import { DictCode } from '@/constants';
import type { IconfontIcon } from '@/icons/fonts/iconfont';

import type { Component, ComponentPublicInstance } from 'vue';
import type { StepProps, UploadProps } from 'ant-design-vue';
import type { Rule, RuleObject } from 'ant-design-vue/es/form';
import type { FormLabelAlign } from 'ant-design-vue/es/form/interface';
import type { ProtocolConfigMethod } from '@/constants';

export interface ApiResponse<T> {
  data: T;
  code: number;
  msg: string;
}

export interface PageData<T> {
  records: T[];
  total: number;
  pageIndex: number;
  pageSize: number;
  pageNum: number;
}

export interface PageParams {
  pageIndex: number;
  pageSize: number;
  pageSorts?: {
    column: string;
    asc: boolean;
  }[];
}

export interface OptionItem<T> {
  value: T;
  label: string;
}

export type CheckedType = boolean | string | number;

export interface IconObject {
  name: IconfontIcon;
  size?: number;
  color?: string;
}

export type FormRules<T> = {
  [K in keyof T]?: Rule[];
} & {
  [key: string]: Rule[];
};

export type RuleValidator<T> = (rule: RuleObject, value: T, callback: (error?: string) => void) => Promise<void>;

export interface DictTypeDataParams {
  id?: number;
  dictCode?: DictCode;
}

export interface DictTypeData {
  dictId: number;
  dictCode: string;
  dictName: string;
  dictEngName: string;
  dictOrderNum: number | null;
  dictTypeDataList: DictValue[];
}

export interface DictValue {
  dictValueId: number;
  dictValue: string;
  dictEngValue: string;
  dictValueOrderNum: number;
  isDefault: boolean | null;
}

export interface UseGuideStepItem extends StepProps {
  title: string;
  stepTitle?: string;
  stepDescription?: string;
  hideHeader?: boolean;
  hideHeaderDivider?: boolean;
  headerMargin?: number;
  component: Component;
  contentOffset?: number;
  formLayout?: 'horizontal' | 'vertical' | 'inline';
  labelAlign?: FormLabelAlign;
  labelCol?: { span?: string | number };
  wrapperCol?: { span?: string | number };
  isLastStep?: boolean;
  exportButtonShow?: boolean;
  nextStepButtonHide?: boolean;
  nextStepButtonText?: string;
  nextStepButtonDisabled?: boolean;
}

export interface UseGuideStepItemProps<T> {
  form: T;
  steps: UseGuideStepItem[];
  stepIndex: number;
  goToStep: (index: number) => void;
}

export type UseGuideStepItemExpose = {
  exportData?: () => void | Promise<void>;
  finish?: () => void | Promise<void>;
};

export type UseGuideStepItemInstance = ComponentPublicInstance<unknown, UseGuideStepItemExpose>;

export interface SetupProtocolForm {
  protocolType?: string;
  protocolInfo: Partial<ProtocolBaseInfo>;
  protocolFile: UploadProps['fileList'];
  configMethod: ProtocolConfigMethod;
  deviceType?: string;
}

export interface CustomParamsForm {
  gatewayParamName: string;
  gatewayParamCode: string;
  unit: string;
  module: string;
  readWriteType: string;
  parsingType: string;
  writeFunctionCode: string;
  readFunctionCode: string;
  addressLength: number;
  registerAddress: number;
  coefficient: number;
  isHighFrequencyParameter: string;
  readCalculationFormula: string;
  writeCalculationFormula: string;
  decimalPlaces: number;
  contiguousAddressingRange: number;
}

export type ProtocolListData = PageData<ProtocolBaseInfo>;

export interface ProtocolBaseInfo {
  id: number;
  protocolName: string;
  protocolType: string;
  deviceType: string;
  deviceTypeId: number | null;
  dataBit: 5 | 6 | 7 | 8;
  parityBit: 'N' | 'O' | 'E';
  stopBit: '1' | '1.5' | '2';
  baudRate: number;
  dataSendInterval: number;
  highFreqSendInterval: number;
  readTimeout: number;
  nextDataReadDelay: number;
  nextRoundDataReadDelay: number;
  readContinuousAddr: string;
  readContinuousAddrCode: number;
  readContinuousAddrLength: number;
  byteOrder: string;
  byteOrderCode: string;
  addrOrder: string;
  addrOrderCode: string;
}

export interface ProtocolListQuery extends PageParams {
  searchContent: string;
}

export type ProtocolParamData = PageData<ProtocolParamInfo>;

export interface ProtocolParamInfo {
  id: number;
  createTime: string;
  updateTime: string;
  createUserId: number;
  updateUserId: number;
  baseInfoId: number;
  platformParamCode: string;
  platformParamName: string;
  gatewayParamCode: string;
  gatewayParamName: string;
  paramCode: string;
  paramName: string;
  unit: string;
  module: string;
  readWriteType: string;
  readWriteTypeCode: string;
  readFuncCode: string;
  writeFuncCode: string;
  registerAddr: string;
  addrNumber: string;
  registerType: string;
  registerTypeCode: string;
  parsingType: string;
  parsingTypeCode: string;
  addrLength: number;
  wordLength: number;
  wordLengthCode: string;
  quantity: number;
  coefficient: number;
  isHighFreqParam: string;
  isHighFreqParamCode: string;
  readCalcFormula: string;
  writeCalcFormula: string;
  decimalPlace: number;
}

export interface ProtocolParamSearchParams extends PageParams {
  baseInfoId: number;
  paramCode?: string;
  paramName?: string;
}

export type ProtocolStandardParamData = PageData<ProtocolStandardParam>;

export interface ProtocolStandardParam {
  id: number;
  createTime: string;
  updateTime: string;
  createUserId: number;
  updateUserId: number;
  paramCode: string;
  paramName: string;
  unit: string;
  module: string;
  deviceTypeId: number;
  deviceType: string;
  enabled: string;
}

export interface ProtocolStandardParamQuery extends PageParams {
  paramCode?: string;
  paramName?: string;
}

export interface RegisterGatewayForm extends EquipmentInformation {
  snCode: string;
  password: string;
  modelId: number;
  linkType: string;
  id: number;
  interfaceId?: number;
  protocolId?: number;
  linkName: string;
  protocolName: string;
}

export interface VerificationEquipment {
  snCode: string;
  password: string;
}

export interface GatewayInformation {
  createTime: string;
  createUserId: string;
  deleted: number;
  id: number;
  isRegister: number;
  modelId: number;
  password: string;
  snCode: string;
  state: number;
  updateTime: string;
  updateUserId: number;
}

export interface GatewayModelInfo {
  createTime: string;
  createUserId: string;
  deleted: number;
  docUrl: string;
  iconUrl: string;
  id: number;
  interfaceId: string;
  interfaceNum: string;
  modelName: string;
  surfMode: string;
  surfModeEn: string;
  updateTime: string;
  updateUserId: string;
}

export interface InterfaceNum {
  COM: number;
  DI: number;
  DO: number;
  LAN: number;
  WAN: number;
}

export interface EquipmentInformation {
  state: number;
  docUrl: string;
  iconUrl: string;
  interfaceNum: string;
  modelName: string;
  surfMode: string | string[];
  surfModeEn: string | string[];
  show: boolean;
  judgmentRegistration: boolean;
}

export interface GatewayInterface {
  comment: string;
  createTime: string;
  createUserId: string;
  deleted: number;
  dictCode: string;
  dictEngValue: string;
  dictValue: string;
  enabled: number;
  id: number;
  isDefault: string;
  orderNum: number;
  tag: string;
  updateTime: string;
  updateUserId: string;
}

export interface AddInterface {
  interfaceId?: number;
  linkName: string;
  gatewayId: number;
  protocolType: string;
}

export interface InterfaceList {
  value: string;
  label: string;
}

export interface InterfaceData {
  id: number;
  createTime: string;
  updateTime: string;
  createUserId: number;
  updateUserId: number;
  linkName: string;
  gatewayId: number;
  interfaceId: number;
  protocolType: string;
  bindState: number;
  dataBit: number;
  parityBit: string;
  stopBit: string;
  baudRate: number;
  readTimeout: number;
  nextDataReadDelay: number;
  nextRoundDataReadDelay: number;
  interfaceType: string;
}

export interface AgreementUpdate {
  id: number;
  linkName: string;
  gatewayId: number;
  interfaceId: number;
  bindState: number;
  dataBit: string;
  parityBit: string;
  stopBit: string;
  baudRate: number;
  readTimeout: number;
  nextDataReadDelay: number;
  nextRoundDataReadDelay: number;
}

export interface AgreementData {
  protocolType: string;
  station: string;
  name: string;
  protocolName: string;
  dataSendInterval: number;
  highFreqSendInterval: number;
  protocolId?: number;
  isStandard: string;
  deviceName: string;
}

export interface AgreementForm {
  baudRate: number;
  dataBit: string;
  parityBit: string;
  stopBit: string;
  readTimeout: number;
  nextDataReadDelay: number;
  nextRoundDataReadDelay: number;
}

export interface EquipmentGroup {
  pageIndex: number;
  pageSize: number;
  content: string;
}

export interface DeviceGroupItem {
  id: number;
  createTime: Date | null;
  updateTime: Date | null;
  createUserId: number | null;
  updateUserId: number | null;
  groupName: string;
  comment: string | null;
  parentId: number;
  userId: number;
  deleted: boolean | null;
  deviceGroupChilds: DeviceGroupChild[];
}

export interface DeviceGroupChild {
  id: number;
  groupName: string;
  comment: string | null;
  parentId: number;
  userId: number;
}

export interface ListInfo {
  dataType: number;
}

export interface ProtocolList {
  pageIndex: number;
  pageSize: number;
  searchContent: string;
}

export interface EquipmentInformationForm {
  groupId: number;
  deviceData: number[];
  deviceType: string;
  deviceName: string;
  brand: number;
  model: number;
  modelType: number;
  controlType: number;
  compressionLevel: number;
  voltageLevel: number;
  powerRating: string;
  powerUnload: string;
  maximumFlow: string;
  pressure: string;
  pressureMax: string;
  productionDate: string;
  productionNum: string;
  deviceNum: string;
  mainTechData: string;
  mountedPosition: string;
  department: string;
  respPerson: string;
  phone: string;
  serviceLife?: number;
  status: string;
  remarks: string;
  devId: number;
  imgUrl: string;
}

export interface EquipmentTypeItem {
  id: number;
  createTime: string;
  updateTime: string;
  createUserId: number;
  updateUserId: number;
  dataType: number;
  dataName: string;
}

export type ProtocolItemData = PageData<ProtocolItem>;
export interface ProtocolItem {
  id: number;
  createTime: string;
  updateTime: string;
  createUserId: number;
  updateUserId: number;
  protocolName: string;
  protocolType: string;
  deviceTypeId: number | null;
  deviceType: string;
  dataBit: number;
  parityBit: string;
  stopBit: string;
  baudRate: number;
  dataSendInterval: number;
  highFreqSendInterval: number;
  readTimeout: number | null;
  nextDataReadDelay: number;
  nextRoundDataReadDelay: number;
  addrOrder: string;
  addrOrderCode: string;
  byteOrder: string;
  byteOrderCode: string;
  attachment: string;
  readContinuousAddr: string;
  readContinuousAddrCode: number;
  readContinuousAddrLength: number;
}

export interface ProtocolsItem {
  /*协议ID */
  protocolId?: number;

  /*从站号 */
  station: string;

  /*是否平台标准协议 */
  isStandard: string;

  /*普通数据上报频率 */
  dataSendInterval: number;

  /*高频发送间隔 */
  highFreqSendInterval: number;
}
export interface ProtocolReset {
  linkId: number;
  protocols: ProtocolsItem[];
}

export interface VerificationAgreement {
  id: number;
  createTime: string;
  updateTime: string;
  createUserId: number;
  updateUserId: number;
  linkId: number;
  protocolId: number;
  station: number;
  isStandard: number;
  dataSendInterval: number;
  highFreqSendInterval: number;
  protocolName: string;
  protocolType: string;
  deviceName: string;
}

export interface ProtocolListItem {
  pageIndex: number;
  pageSize: number;
  id?: number;
  linkId?: number;
  readWriteTypeCode?: string;
  monitorType?: string;
  searchContent?: string;
}

export type ProtocolListPageItemData = PageData<ProtocolListPageItem>;
export interface ProtocolListPageItem {
  id: number;
  createTime: string | null;
  updateTime: string | null;
  createUserId: number | null;
  updateUserId: number | null;
  baseInfoId: number | null;
  platformParamCode: string | null;
  platformParamName: string | null;
  gatewayParamCode: string;
  gatewayParamName: string;
  paramCode: string;
  paramName: string;
  unit: string | null;
  module: number;
  readWriteType: string | null;
  readWriteTypeCode: string | null;
  readFuncCode: string | null;
  writeFuncCode: string | null;
  registerAddr: string | null;
  addrNumber: number | null;
  registerType: string | null;
  registerTypeCode: string | null;
  parsingType: string | null;
  parsingTypeCode: string | null;
  addrLength: number | null;
  wordLength: number | null;
  wordLengthCode: string | null;
  quantity: number | null;
  coefficient: number;
  isHighFreqParam: boolean | null;
  isHighFreqParamCode: string | null;
  readCalcFormula: string | null;
  writeCalcFormula: string | null;
  decimalPlace: number | null;
}

export type SerialNumberItemData = PageData<SerialNumberItem>;
export interface SerialNumberItem {
  id: number;
  createTime: string;
  updateTime: string;
  createUserId: number;
  updateUserId: number;
  snCode: string;
  password: string;
  modelId: number;
  isRegister: number;
  state: number;
  deleted: number;
  modelName: string;
  links: PhysicalInterfaceList[];
}

export interface PhysicalInterfaceList {
  linkId: number;
  linkName: string;
}

export type ListEquipmentParametersItemData = PageData<ListEquipmentParametersItem>;

export interface ListEquipmentParametersItem {
  gatewayParamCode: string;
  gatewayParamName: string;
  id: number;
  parsingType?: number;
  readWriteType?: string;
  readWriteTypeCode?: string;
  unit: string;
  groupId?: number;
  groupSerialNum?: number;
  groupParamSerialNum?: number;
  isProcessData: boolean;
  gatewayId: number;
  deviceParamCode: string;
  deviceParamName: string;
  groupName: string;
  groupIdShow: boolean;
  linkId: number;
}

export interface EquipmentUpdateForm {
  deviceId: number;
  gatewayId: number;
  gatewayProtocolId: number;
  linkId?: number;
}

export interface GetListItem {
  deviceId: number;
  monitorType: string;
  pageIndex: number;
  pageSize: number;
  gatewayId?: number;
  createUserId?: number;
}

export interface PostProtocolPage {
  pageIndex: number;
  pageSize: number;
  deviceIds: number[];
  gatewayIds: number[];
}

export type PostProtocolPageItemData = PageData<PostProtocolPageItem>;
export interface PostProtocolPageItem {
  id: number;
  createTime: string;
  updateTime: string;
  createUserId: number;
  updateUserId: number;
  baseInfoId: number;
  platformParamCode?: string;
  platformParamName?: string;
  gatewayParamCode?: string;
  gatewayParamName?: string;
  paramCode: string;
  paramName: string;
  unit?: string;
  module: string;
  readWriteType: string;
  readWriteTypeCode: string;
  readFuncCode: string;
  writeFuncCode?: string;
  registerAddr: string;
  addrNumber?: string;
  registerType: string;
  registerTypeCode?: string;
  parsingType: string;
  parsingTypeCode: string;
  addrLength: number;
  wordLength?: string;
  wordLengthCode?: string;
  quantity?: string;
  coefficient: number;
  isHighFreqParam: string;
  isHighFreqParamCode: string;
  readCalcFormula?: string;
  writeCalcFormula?: string;
  decimalPlace?: number;
  deviceName: string;
  deviceNum: string;
  groupSerialNum: number;
  groupParamSerialNum: number;
  deviceId: number;
  isProcessData: boolean;
  gatewayId: number;
  deviceParamCode: string;
  deviceParamName: string;
  groupId?: number;
  deviceParamCodeShow: boolean;
  deviceParamNameShow: boolean;
  groupIdShow: boolean;
  groupParamSerialNumShow: boolean;
}

export interface ProtocolGatewayListListItem {
  pageIndex: number;
  pageSize: number;
  snCode?: number;
  gatewayId?: number;
  searchContent: string;
  monitorType: string;
}

export interface ParameterVerification {
  id: number;
  deviceParamGroupName: string;
  valueVos: ParameterVerificationList[];
}

export interface ParameterVerificationList {
  baseInfoId: number;
  platformParamCode: string;
  platformParamName: string;
  gatewayParamCode: string;
  gatewayParamName: string;
  paramCode: string;
  paramName: string;
  unit: string;
  module: string;
  readWriteType: string;
  readWriteTypeCode: string;
  readFuncCode: string;
  writeFuncCode: string;
  registerAddr: string;
  addrNumber: string;
  registerType: string;
  registerTypeCode: string;
  parsingType: string;
  parsingTypeCode: string;
  addrLength: number;
  wordLength: string;
  wordLengthCode: string;
  quantity: number;
  coefficient: number;
  isHighFreqParam: string;
  isHighFreqParamCode: string;
  readCalcFormula: string;
  writeCalcFormula: string;
  decimalPlace: number;
  valueId: number;
  value: number | string;
}

export interface GroupingList {
  groupName: string;
  serialNum?: number;
}

export interface GroupingListData {
  id: number;
  createTime: string;
  updateTime: string;
  createUserId: number;
  updateUserId: number;
  groupName: string;
  deviceId: number;
  serialNum: number;
}

export interface DevicesList {
  pageIndex: number;
  pageSize: number;
  groupId?: number;
  deviceType?: number;
  searchContent?: string;
  brandName?: string;
  modelName?: string;
  gatewaySnCode?: string;
  deviceName?: string;
  runningStatus?: number;
  errorStatus?: number;
}

export interface ListInterfaces {
  id: number;
  createTime: string;
  updateTime: string;
  createUserId: number;
  updateUserId: number;
  modelId: number;
  interfaceType: string;
  name: string;
}

export interface ListPhysicalInterfaces {
  id: number;
  createTime: string;
  updateTime: string;
  createUserId: number;
  updateUserId: number;
  interfaceId: number;
  protocolName: string;
  orderNum: number;
}

export interface CustomizationData {
  deviceParamCode: string;
  paramNumShow: boolean;
  deviceParamName: string;
  paramNameShow: boolean;
  customFormula: string;
  customFormulaShow: boolean;
  unit: string;
  unitShow: boolean;
  decimalDigits?: number;
  decimalDigitsShow: boolean;
  paramGroupId?: number;
  paramGroupName: string;
  paramGroupIdShow: boolean;
  groupSerialNum?: number;
  groupSerialNumShow: boolean;
  groupParamSerialNum?: number;
  isProcessData: boolean;
}

export interface CustomParameters {
  customFormula: string;
  unit: string;
  decimalDigits?: number;
  deviceId: number;
  isProcessData: boolean;
  paramGroupId?: number;
  groupParamSerialNum?: number;
  paramType?: number;
  deviceParamCode: string;
  deviceParamName: string;
  paramGroupName: string;
}

export interface SubmitSorting {
  protocolParamId?: number;
  paramGroupId?: number;
  serialNum?: number;
  paramType?: number;
  isProcessData?: boolean;
  deviceParamName?: string;
  deviceParamCode?: string;
  groupId?: number;
}

export type DevicesListItemData = PageData<DevicesListItem>;
export interface DevicesListItem {
  id: number;
  deviceName: string;
  groupId: number;
  deviceType: number;
  userId: number;
  brand: number;
  model: number;
  modelType: number;
  controlType: number;
  compressionLevel: number;
  voltageLevel: number;
  powerRating: number;
  powerUnload: number;
  maximumFlow: number;
  pressure: number;
  pressureMax: number;
  productionDate: string;
  productionNum: string;
  mainTechData: string;
  mountedPosition: string;
  department: string;
  respPerson: string;
  phone: string;
  serviceLife: number;
  status: number;
  remarks: string;
  deviceNum: string;
  deleted: boolean;
  deviceGroup: DeviceGroup;
  gatewayInfos: GatewayInfos[];
  protocolParamInfos: ProtocolParamInfos[];
  groupName: string;
  deviceTypeName: string;
  brandName: string;
  modelName: string;
  modelTypeName: string;
  controlTypeName: string;
  compressionLevelName: string;
  voltageLevelName: string;
}

export interface DeviceGroup {
  id: number;
  createTime: string;
  updateTime: string;
  createUserId: number;
  updateUserId: number;
  groupName: string;
  comment: string;
  parentId: number;
  userId: number;
  deleted: string;
}

export interface GatewayInfos {
  id: number;
  createTime: string;
  updateTime: string;
  createUserId: number;
  updateUserId: number;
  snCode: string;
  password: string;
  modelId: number;
  isRegister: string;
  state: string;
  deleted: string;
}

export interface ProtocolParamInfos {
  id: number;
  createTime: string;
  updateTime: string;
  createUserId: number;
  updateUserId: number;
  baseInfoId: number;
  orgId: number;
  recognizeResult: string;
  candidateResults: string;
  platformParamCode: string;
  platformParamName: string;
  gatewayParamCode: string;
  gatewayParamName: string;
  paramCode: string;
  paramName: string;
  unit: string;
  module: string;
  readWriteType: string;
  readWriteTypeCode: string;
  readFuncCode: string;
  writeFuncCode: string;
  registerAddr: string;
  addrNumber: string;
  registerType: string;
  registerTypeCode: string;
  parsingType: string;
  parsingTypeCode: string;
  addrLength: number;
  wordLength: string;
  wordLengthCode: string;
  quantity: number;
  coefficient: number;
  isHighFreqParam: string;
  isHighFreqParamCode: string;
  readCalcFormula: string;
  writeCalcFormula: string;
  decimalPlace: number;
  isDraft: string;
}

export interface GatewayBody {
  pageIndex: number;
  pageSize: number;
  searchContent: string;
  state: number;
}

export type GatewayListItemData = PageData<GatewayListItem>;
export interface GatewayListItem {
  id: number;
  createTime: string;
  updateTime: string;
  createUserId: number;
  updateUserId: number;
  snCode: string;
  password: string;
  modelId: number;
  isRegister: string;
  state: string;
  deleted: string;
  modelName: string;
  protocolParamInfoQueryVos: protocolParamInfo[];
}

export interface protocolParamInfo {
  baseInfoId: number;
  orgId: number;
  recognizeResult: string;
  candidateResults: string;
  platformParamCode: string;
  platformParamName: string;
  gatewayParamCode: string;
  gatewayParamName: string;
  paramCode: string;
  paramName: string;
  unit: string;
  module: string;
  readWriteType: string;
  readWriteTypeCode: string;
  readFuncCode: string;
  writeFuncCode: string;
  registerAddr: string;
  addrNumber: string;
  registerType: string;
  registerTypeCode: string;
  parsingType: string;
  parsingTypeCode: string;
  addrLength: number;
  wordLength: string;
  wordLengthCode: string;
  quantity: number;
  coefficient: number;
  isHighFreqParam: string;
  isHighFreqParamCode: string;
  readCalcFormula: string;
  writeCalcFormula: string;
  decimalPlace: number;
  isDraft: string;
}

export interface GatewayParameterBody {
  pageIndex: number;
  pageSize: number;
  gatewayId: number;
  gatewayLinkProtocolId: number;
}

export type GatewayParameterItemData = PageData<GatewayParameterItem>;
export interface GatewayParameterItem {
  id: number;
  paramName: string;
  paramCode: string;
  gatewayParamName: string;
  gatewayParamCode: string;
  unit: string;
  readWriteType: string;
  readWriteTypeCode: string;
  value: string | number;
  time: string;
  monitorStatus: string;
}

export interface EquipmentDetailsItem {
  deviceQueryVo: BasicInformation;
  gatewayInfoVos: AssociatedGatewayParameters[];
  protocolParamDeviceInfoVos: ConfigureDeviceParameters[];
  protocolParamCustomDevVos: CustomParametersItem[];
}

export interface AssociatedGatewayParameters {
  id: number;
  createTime: string;
  updateTime: string;
  createUserId: number;
  updateUserId: number;
  snCode: string;
  password: string;
  modelId: number;
  isRegister: string;
  state: string;
  deleted: string;
  modelName: string;
  linkName: string;
  linkId: number;
  protocolParamInfoQueryVos: protocolParamInfo[];
}

export interface BasicInformation {
  id: number;
  deviceName: string;
  groupId: number;
  deviceType: number;
  userId: number;
  brand: number;
  model: number;
  modelType: number;
  controlType: number;
  compressionLevel: number;
  voltageLevel: number;
  powerRating: number;
  powerUnload: number;
  maximumFlow: number;
  pressure: number;
  pressureMax: number;
  productionDate: string;
  productionNum: string;
  mainTechData: string;
  mountedPosition: string;
  department: string;
  respPerson: string;
  phone: string;
  serviceLife: number;
  status: number;
  remarks: string;
  deviceNum: string;
  runningStatus: number;
  deleted: boolean;
  deviceGroup: DeviceGroup;
  gatewayInfos: GatewayInfos[];
  protocolParamInfos: ProtocolParamInfos[];
  groupName: string;
  deviceTypeName: string;
  brandName: string;
  modelName: string;
  modelTypeName: string;
  controlTypeName: string;
  compressionLevelName: string;
  voltageLevelName: string;
  errorStatus: number;
}

export interface ConfigureDeviceParameters {
  baseInfoId: number;
  orgId: number;
  recognizeResult: string;
  candidateResults: string;
  platformParamCode: string;
  platformParamName: string;
  gatewayParamCode: string;
  gatewayParamName: string;
  paramCode: string;
  paramName: string;
  unit: string;
  module: string;
  readWriteType: string;
  readWriteTypeCode: string;
  readFuncCode: string;
  writeFuncCode: string;
  registerAddr: string;
  addrNumber: string;
  registerType: string;
  registerTypeCode: string;
  parsingType: string;
  parsingTypeCode: string;
  addrLength: number;
  wordLength: string;
  wordLengthCode: string;
  quantity: number;
  coefficient: number;
  isHighFreqParam: string;
  isHighFreqParamCode: string;
  readCalcFormula: string;
  writeCalcFormula: string;
  decimalPlace: number;
  isDraft: string;
  id: number;
  deviceParamCode: string;
  deviceParamName: string;
  isProcessData: number;
  gatewayId: string;
  groupSerialNum: number;
  groupParamSerialNum: number;
  groupId: number;
  snCode: string;
  serialNum: number;
  groupName: string;
  linkId: string;
}

export interface CustomParametersItem {
  id: number;
  customFormula: string;
  unit: string;
  decimalDigits: number;
  deviceId: number;
  serialNum: number;
  isProcessData: boolean;
  groupSerialNum: number;
  groupParamSerialNum: number;
  deviceParamCode: string;
  deviceParamName: string;
  groupName: string;
}

export interface AllDevicesList {
  id: number;
  createTime: string;
  updateTime: string;
  createUserId: number;
  updateUserId: number;
  deviceName: string;
  groupId: number;
  deviceType: number;
  userId: number;
  brand: number;
  model: number;
  modelType: number;
  controlType: number;
  compressionLevel: number;
  voltageLevel: number;
  powerRating: number;
  powerUnload: number;
  maximumFlow: number;
  pressure: number;
  pressureMax: number;
  productionDate: string;
  productionNum: string;
  mainTechData: string;
  mountedPosition: string;
  department: string;
  respPerson: string;
  phone: string;
  serviceLife: number;
  status: number;
  remarks: string;
  deleted: number;
  deviceNum: string;
  runningStatus: string;
}

export interface GatewayQuery extends PageParams {
  searchContent: string;
  state: number;
  total: number;
}

export interface GatewayLinkProtocolQuery {
  linkId: number;
  monitorType: string;
  searchContent: string;
}

export interface DeviceBindQuery {
  deviceParamGroups: DeviceParamGroups[];
  deviceGateways: DeviceGateways[];
  deviceParamGroupRels: DeviceParamGroupRels[];
  protocolParamCustomDevDTOS: CustomParameters[];
}

export interface DeviceParamGroups {
  groupName: string;
  deviceId: number;
  serialNum?: number;
}

export interface DeviceGateways {
  deviceId: number;
  gatewayId: number;
  gatewayProtocolId: number;
  linkId: number;
}

export interface DeviceParamGroupRels {
  protocolParamId: number;
  paramGroupName: string;
  paramType: number;
  deviceParamCode: string;
  deviceParamName: string;
  isProcessData: boolean;
}

export interface ParamValueListAutomaticQuery {
  linkId: number;
  deviceTypeId: number;
}

export interface ParamValueListAutomaticData {
  id: number;
  createTime: string;
  updateTime: string;
  createUserId: number;
  updateUserId: number;
  baseInfoId: number;
  orgId: number;
  recognizeResult: string;
  candidateResults: string;
  platformParamCode: string;
  platformParamName: string;
  gatewayParamCode: string;
  gatewayParamName: string;
  paramCode: string;
  paramName: string;
  unit: string;
  module: string;
  readWriteType: string;
  readWriteTypeCode: string;
  readFuncCode: string;
  writeFuncCode: string;
  registerAddr: string;
  addrNumber: string;
  registerType: string;
  registerTypeCode: string;
  parsingType: string;
  parsingTypeCode: string;
  addrLength: number;
  wordLength: string;
  wordLengthCode: string;
  quantity: number;
  coefficient: number;
  isHighFreqParam: string;
  isHighFreqParamCode: string;
  readCalcFormula: string;
  writeCalcFormula: string;
  decimalPlace: number;
  isDraft: string;
}
